# 开发人员： Xiaoqiang
# 微信公众号: xiaoqiangclub
# 开发时间： 2025/4/21 19:51
# 文件名称： error_code.py
# 项目描述： 错误代码
# 开发工具： PyCharm
import logging
from wechat_draft.utils.logger import log


def handle_error(result: dict, logger: logging.Logger = log):
    """
    错误码
    https://developers.weixin.qq.com/doc/oplatform/Return_codes/Return_code_descriptions_new.html
    
    :param result: 接口返回的JSON数据包
    :param logger: 日志记录器
    """
    error_map = {
        -1: "系统繁忙，此时请开发者稍候再试",
        0: "请求成功",
        40001: "获取access_token时AppSecret错误，或者access_token无效。请开发者认真比对AppSecret的正确性，或查看是否正在为恰当的公众号调用接口",
        40002: "不合法的凭证类型",
        40003: "不合法的OpenID，请开发者确认OpenID（该用户）是否已关注公众号，或是否是其他公众号的OpenID",
        40004: "不合法的媒体文件类型",
        40007: "无效的media_id（请检查素材是否存在或为永久素材）",
        40008: "不合法的消息类型",
        40013: "不合法的AppID，请开发者检查AppID的正确性，避免异常字符，注意大小写",
        40014: "不合法的access_token，请开发者认真比对access_token的有效性（如是否过期），或查看是否正在为恰当的公众号调用接口",
        40015: "不合法的菜单类型",
        40021: "不合法的菜单版本号",
        41001: "缺少access_token参数",
        41004: "缺少secret参数",
        41005: "缺少多媒体文件数据",
        41006: "缺少media_id参数",
        41007: "缺少子菜单数据",
        41008: "缺少oauth code",
        42007: "用户修改微信密码，accesstoken和refreshtoken失效，需要重新授权",
        43101: "用户拒绝接收消息",
        45003: "标题长度超过限制（最多64字）",
        45009: "接口调用超过限制",
        48001: "api功能未授权",
        49003: "用户未授权该api",
        50001: "权限不足（请检查appsecret是否正确）",
        50002: "用户受限，可能是违规后接口被封禁",
        53401: "封面图片尺寸不符合要求，请上传尺寸接近900px * 500px，宽高比接近16:9的图片",
        53404: "账号已被限制带货能力，请删除商品后重试",
        53405: "插入商品信息有误，请检查后重试，请检查请求参数是否合法，以及商品状态是否正常",
        53406: "请先开通带货能力",
        53503: "该草稿未通过发布检查",
        53504: "需前往公众平台官网使用草稿",
        53505: "请手动保存成功后再发表",
        53600: "Article ID 无效",
        61451: "参数错误 (invalid parameter)",
        65305: "个性化菜单数量受限",
        65306: "不支持个性化菜单的帐号",
        65307: "个性化菜单信息为空",
        65308: "包含没有响应类型的button",
        65309: "个性化菜单开关处于关闭状态",
        65310: "填写了省份或城市信息，国家信息不能为空",
        65311: "填写了城市信息，省份信息不能为空",
        65312: "不合法的国家信息",
        65313: "不合法的省份信息",
        65314: "不合法的城市信息",
        65316: "该公众号的菜单设置了过多的域名外跳（最多跳转到3个域名的链接）",
        88000: "没有留言权限",
        88001: "数据不存在",
        88008: "评论不存在",
        87009: "回复不存在",
        89001: "素材类型错误（仅支持永久素材）",
        89501: "此IP正在等待管理员确认,请联系管理员",
        89503: "此IP调用需要管理员确认,请联系管理员",
        89506: "24小时内该IP被管理员拒绝调用两次，24小时内不可再使用该IP调用",
        89507: "1小时内该IP被管理员拒绝调用一次，1小时内不可再使用该IP调用",
        9001001: "POST数据参数不合法",
        9001002: "远端服务不可用",
        9001003: "Ticket不合法",
        9001004: "获取摇周边用户信息失败",
        9001005: "获取商户信息失败",
        9001006: "获取OpenID失败",
        9001007: "上传文件缺失",
        9001008: "上传素材的文件类型不合法",
        9001009: "上传素材的文件尺寸不合法",
        9001010: "上传失败",
        9001020: "帐号不合法",
        9001021: "已有设备激活率低于50%，不能新增设备",
        9001022: "设备申请数不合法，必须为大于0的数字",
        9001023: "已存在审核中的设备ID申请",
        9001024: "一次查询设备ID数量不能超过50",
        9001025: "设备ID不合法",
        9001028: "一次删除页面ID数量不能超过10",
        9001031: "时间区间不合法",
        9001032: "保存设备与页面的绑定关系参数错误",
        9001033: "门店ID不合法",
        9001034: "设备备注信息过长",
        9001035: "设备申请参数不合法",
        -41000: "不合法的access_token，通常由于Access Token过期、获取错误、被重复使用或缓存问题等引起，需重新获取有效token并确保其正确使用和及时刷新"
    }

    # 错误情况下的返回JSON数据包示例 {"errcode":40004,"errmsg":"invalid media type"}
    errcode = result.get("errcode", -1)
    errmsg = result.get("errmsg", "未知错误")

    error_desc = error_map.get(errcode, f"未知错误代码: {errcode}（原始错误信息：{errmsg}）")
    logger.error(f"错误码 {errcode}：{error_desc}")
